@@ -49,9 +49,9 @@ def pipulate(tab, rows, cols, columns=None):
         columns = tab.range(row1, col1, row1, col2)
         columns = [cc(x.col) for x in columns]
     df = pd.DataFrame(list_of_lists, columns=columns)
-    print('cl, df = gs.pipulate(%s, rows=%s, cols=%s) successful.' % (tab.title, rows, cols))
+    print('cl, df = gs.pipulate("%s", rows=%s, cols=%s) was successful.' % (tab.title, rows, cols))
     print("You may now manipulate the DataFrame but maintain its (%s x %s) shape." % df.shape)
-    print('To update the GSheet with changes, gs.populate(%s, cl, df)' % tab.title)
+    print('To update the GSheet with changes, gs.populate("%s", cl, df)' % tab.title)
     return cl, df
 
 
@@ -67,7 +67,7 @@ def populate(tab, cl, df):
         tab.update_cells(cl)
     else:
         raise SystemExit()
-    print('gs.populate(%s, cl, df) << SUCCESS! GSHEET UPDATED >>' % tab.title)
+    print('gs.populate("%s", cl, df) << GSHEET UPDATED >>' % tab.title)
 
 
 def cl_to_list(cl):
